<?php
namespace Ak\Image\Processor\Adapter;

use Interop\Container\ContainerInterface;
use Laminas\ServiceManager\Exception\ServiceNotCreatedException;
use Laminas\ServiceManager\Factory\FactoryInterface;

/**
 * Stvara novu instancu AdapterChain adaptera.
 *
 * @package Ak\Image\Processor\Adapter
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/image-processor
 */
final class AdapterChainFactory implements FactoryInterface
{
    /**
     * Stvara adapter.
     *
     * @param  ContainerInterface $container
     * @param  string $requestedName
     * @param  null|array $options
     *
     * @return AdapterChain
     */
    public function __invoke(ContainerInterface $container, $requestedName, array $options = null)
    {
        $config = $options ?? [];
        /** @var AdapterPluginManager $adapterManager */
        $adapterManager = $container->get('image_processor.adapters');
        $adapterChain = new AdapterChain();

        foreach (($config['adapters'] ?? []) as $adapter) {
            if (is_array($adapter)) {
                $options = $adapter['options'] ?? [];
                $adapter = $adapter['name'];
            }

            if (is_string($adapter)) {
                $adapter = $adapterManager->get($adapter, $options ?? []);
            }

            if (!$adapter instanceof AdapterInterface) {
                throw new ServiceNotCreatedException(sprintf(
                    "U AdapterChain je moguće dodati samo AdapterInterface, a dobio sam %s.",
                    is_object($adapter) ? get_class($adapter) : gettype($adapter)
                ));
            }

            $adapterChain->addAdapter($adapter);
        }

        return $adapterChain;
    }
}
