<?php
namespace Ak\Image\Processor;

use Interop\Container\ContainerInterface;
use Interop\Container\Exception\ContainerException;
use Laminas\ServiceManager\AbstractPluginManager;
use Laminas\ServiceManager\Exception\ServiceNotCreatedException;
use Laminas\ServiceManager\Exception\ServiceNotFoundException;
use Laminas\ServiceManager\Factory\FactoryInterface;

/**
 * Stvara novu instancu Image procesora.
 *
 * @package Ak\Image\Processor
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/image-processor
 */
final class ProcessorFactory implements FactoryInterface
{
    /**
     * Create an object
     *
     * @param  ContainerInterface $container
     * @param  string $requestedName
     * @param  null|array $options
     * @return object
     * @throws ServiceNotFoundException if unable to resolve the service.
     * @throws ServiceNotCreatedException if an exception is raised when
     *     creating a service.
     * @throws ContainerException if any other error occurs
     */
    public function __invoke(ContainerInterface $container, $requestedName, array $options = null)
    {
        $config = $container->get('config')['image_processor'] ?? [];

        $processor = $config['adapter'] ?? 'pass_through';
        $options = [];

        if (is_array($processor)) {
            $options = $processor['options'] ?? [];
            $processor = $processor['name'];
        }

        if (is_string($processor)) {
            /** @var AbstractPluginManager $adapters */
            $adapters = $container->get('image_processor.adapters');
            $processor = $adapters->get($processor, $options);
        }

        if (!$processor instanceof ProcessorInterface) {
            throw new ServiceNotCreatedException(sprintf(
                "Processor mora implementirati '%s', a u stvari je '%s'.",
                ProcessorInterface::class,
                is_object($processor) ? get_class($processor) : gettype($processor)
            ));
        }

        return $processor;
    }
}
