<?php
namespace AkTest\Image\Processor\Adapter;

use Ak\Image\Processor\Adapter\AdapterChain;
use Ak\Image\Processor\Adapter\AdapterPluginManager;
use Ak\Image\Processor\Adapter\ImagickAdapter;
use Ak\Image\Processor\Adapter\PassThroughAdapter;
use AkTest\Image\Processor\AbstractTestCase;

/**
 * Class AdapterPluginManagerTest
 *
 * @package AkTest\Image\Processor\Adapter
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/image-processor
 */
final class AdapterPluginManagerTest extends AbstractTestCase
{
    public function testIsRegistered()
    {
        $container = $this->getContainer();

        $this->assertContainerHasService($container, [
            'image_processor.adapters',
            AdapterPluginManager::class,
        ], AdapterPluginManager::class, true);
    }

    public function testCanCreateImagickAdapter()
    {
        $adapters = $this->getAdapterPluginManager();
        $this->assertTrue($adapters->has('imagick'));

        $adapter = $adapters->get('imagick');
        $this->assertInstanceOf(ImagickAdapter::class, $adapter);
    }

    public function testCanCreatePassThroughAdapter()
    {
        $adapters = $this->getAdapterPluginManager();
        $this->assertTrue($adapters->has('pass_through'));

        $adapter = $adapters->get('pass_through');
        $this->assertInstanceOf(PassThroughAdapter::class, $adapter);
    }

    public function testCanCreateAdapterChain()
    {
        $adapters = $this->getAdapterPluginManager();
        $this->assertTrue($adapters->has('adapter_chain'));
        /** @var AdapterChain $adapter */
        $adapter = $adapters->get('adapter_chain', [
            'adapters' => [[
                'name' => 'pass_through',
            ], [
                'name' => 'imagick',
            ]],
        ]);

        $this->assertInstanceOf(AdapterChain::class, $adapter);

        $inner = $adapter->getAdapters();
        $this->assertCount(2, $inner);
        $this->assertInstanceOf(PassThroughAdapter::class, $inner[0]);
        $this->assertInstanceOf(ImagickAdapter::class, $inner[1]);
    }
}