<?php
namespace AkTest\Image\Processor\Adapter;

use Ak\Image\Image;
use Ak\Image\Processor\Adapter\ImagickAdapter;
use Ak\Image\Processor\ResizeMode;
use AkTest\Image\Processor\AbstractTestCase;

/**
 * Class ImagickAdapterTest
 *
 * @package AkTest\Image\Processor
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/image-processor
 */
final class ImagickAdapterTest extends AbstractTestCase
{
    /**
     * @throws \ImagickException
     */
    public function testCanOptimizeJpeg()
    {
        $adapter = new ImagickAdapter([]);

        $raw = new Image(file_get_contents(__DIR__ . '/../data/heavy.jpg'));
        $this->assertTrue($adapter->canProcessImage($raw));

        $optimized = $adapter->optimize($raw);
        $this->assertEquals(file_get_contents(__DIR__ . '/../data/imagick/heavy.jpg'), $optimized->getContents());
    }

    /**
     * @throws \ImagickException
     */
    public function testCanScaleJpeg()
    {
        $adapter = new ImagickAdapter([]);

        $raw = new Image(file_get_contents(__DIR__ . '/../data/flowers.jpg'));

        $resized = $adapter->resize($raw, 200, null, new ResizeMode(ResizeMode::SCALE));
        file_put_contents(__DIR__ . '/../data/imagick/flowers-200x.jpg', $resized->getContents());
        $this->assertEquals(200, $resized->getWidth());
        $this->assertEquals(138, $resized->getHeight());

        $resized = $adapter->resize($raw, null, 200, new ResizeMode(ResizeMode::SCALE));
        file_put_contents(__DIR__ . '/../data/imagick/flowers-x200.jpg', $resized->getContents());
        $this->assertEquals(289, $resized->getWidth());
        $this->assertEquals(200, $resized->getHeight());
    }

    /**
     * @throws \ImagickException
     */
    public function testCanOptimizePng()
    {
        $processor = new ImagickAdapter([]);

        $raw = new Image(file_get_contents(__DIR__ . '/../data/bmw.png'));
        $this->assertTrue($processor->canProcessImage($raw));

        $optimized = $processor->optimize($raw);
        $this->assertEquals(file_get_contents(__DIR__ . '/../data/imagick/bmw.png'), $optimized->getContents());
    }

    /**
     * @throws \ImagickException
     */
    public function testCanResizeFitJpg()
    {
        $processor = new ImagickAdapter([]);

        $raw = new Image(file_get_contents(__DIR__ . '/../data/heavy.jpg'));
        $resized = $processor->resize($raw, 150, 150, new ResizeMode(ResizeMode::FIT));
        file_put_contents(__DIR__ . '/../data/imagick/landscape-fit-150x150.jpg', $resized->getContents());
        $this->assertEquals(150, $resized->getWidth());
        $this->assertEquals(84, $resized->getHeight());

        $raw = new Image(file_get_contents(__DIR__ . '/../data/portrait.jpg'));
        $resized = $processor->resize($raw, 150, 150, new ResizeMode(ResizeMode::FIT));
        file_put_contents(__DIR__ . '/../data/imagick/portrait-fit-150x150.jpg', $resized->getContents());
        $this->assertEquals(113, $resized->getWidth());
        $this->assertEquals(150, $resized->getHeight());
    }

    /**
     * @throws \ImagickException
     */
    public function testCanResizeThumbJpg()
    {
        $processor = new ImagickAdapter([]);

        $raw = new Image(file_get_contents(__DIR__ . '/../data/flowers.jpg'));
        $resized = $processor->resize($raw, 150, 150, new ResizeMode(ResizeMode::THUMB));
        file_put_contents(__DIR__ . '/../data/imagick/landscape-thumb-150x150.jpg', $resized->getContents());
        $this->assertEquals(150, $resized->getWidth());
        $this->assertEquals(150, $resized->getHeight());

        $raw = new Image(file_get_contents(__DIR__ . '/../data/portrait.jpg'));
        $resized = $processor->resize($raw, 150, 150, new ResizeMode(ResizeMode::THUMB));
        file_put_contents(__DIR__ . '/../data/imagick/portrait-thumb-150x150.jpg', $resized->getContents());
        $this->assertEquals(150, $resized->getWidth());
        $this->assertEquals(150, $resized->getHeight());
    }
}