<?php
namespace AkTest\Image\Processor\Adapter;

use Ak\Image\Image;
use Ak\Image\Processor\Adapter\PassThroughAdapter;
use PHPUnit\Framework\TestCase;

/**
 * Class PassThroughProcessorTest
 *
 * @package AkTest\Image\Processor\Adapter
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/image-processor
 */
final class PassThroughProcessorTest extends TestCase
{
    public function testCanProcessAllTypes()
    {
        $adapter = new PassThroughAdapter();
        $image = new Image(fopen(__DIR__ . '/../data/script.sh', 'r'));

        $this->assertTrue($adapter->canProcessImage($image));
    }

    public function testCanOptimizeImage()
    {
        $adapter = new PassThroughAdapter();

        $image = new Image(file_get_contents(__DIR__ . '/../data/image.gif'));
        $optimized = $adapter->optimize($image);

        $this->assertNotSame($image, $optimized);
        $this->assertEquals($image->getContents(), $optimized->getContents());
    }

    public function testCanResizeImage()
    {
        $adapter = new PassThroughAdapter();

        $image = new Image(file_get_contents(__DIR__ . '/../data/image.gif'));
        $resized = $adapter->resize($image);

        $this->assertNotSame($image, $resized);
        $this->assertEquals($image->getContents(), $resized->getContents());
    }
}